-module(bucmime).

-export([type/1, exploded/1]).

type(File) ->
  case filename:extension(bucs:to_binary(File)) of
    <<>> -> <<"application/octet-stream">>;
    Ext -> mime(Ext)
  end.

exploded(File) ->
  case binary:split(type(File), <<"/">>) of
    [Type, Subtype] -> {Type, Subtype};
    _ -> {<<"application">>, <<"octet-stream">>}
  end.

mime(<<".ez">>) -> <<"application/andrew-inset">>;
mime(<<".anx">>) -> <<"application/annodex">>;
mime(<<".atom">>) -> <<"application/atom+xml">>;
mime(<<".atomcat">>) -> <<"application/atomcat+xml">>;
mime(<<".atomsrv">>) -> <<"application/atomserv+xml">>;
mime(<<".lin">>) -> <<"application/bbolin">>;
mime(<<".cu">>) -> <<"application/cu-seeme">>;
mime(<<".davmount">>) -> <<"application/davmount+xml">>;
mime(<<".dcm">>) -> <<"application/dicom">>;
mime(<<".tsp">>) -> <<"application/dsptype">>;
mime(<<".es">>) -> <<"application/ecmascript">>;
mime(<<".otf">>) -> <<"application/font-sfnt">>;
mime(<<".ttf">>) -> <<"application/font-sfnt">>;
mime(<<".pfr">>) -> <<"application/font-tdpfr">>;
mime(<<".woff">>) -> <<"application/font-woff">>;
mime(<<".gz">>) -> <<"application/gzip">>;
mime(<<".hta">>) -> <<"application/hta">>;
mime(<<".jar">>) -> <<"application/java-archive">>;
mime(<<".ser">>) -> <<"application/java-serialized-object">>;
mime(<<".class">>) -> <<"application/java-vm">>;
mime(<<".js">>) -> <<"application/javascript">>;
mime(<<".json">>) -> <<"application/json">>;
mime(<<".m3g">>) -> <<"application/m3g">>;
mime(<<".hqx">>) -> <<"application/mac-binhex40">>;
mime(<<".nb">>) -> <<"application/mathematica">>;
mime(<<".nbp">>) -> <<"application/mathematica">>;
mime(<<".mbox">>) -> <<"application/mbox">>;
mime(<<".mdb">>) -> <<"application/msaccess">>;
mime(<<".doc">>) -> <<"application/msword">>;
mime(<<".dot">>) -> <<"application/msword">>;
mime(<<".mxf">>) -> <<"application/mxf">>;
mime(<<".bin">>) -> <<"application/octet-stream">>;
mime(<<".oda">>) -> <<"application/oda">>;
mime(<<".opf">>) -> <<"application/oebps-package+xml">>;
mime(<<".ogx">>) -> <<"application/ogg">>;
mime(<<".one">>) -> <<"application/onenote">>;
mime(<<".onetoc2">>) -> <<"application/onenote">>;
mime(<<".onetmp">>) -> <<"application/onenote">>;
mime(<<".onepkg">>) -> <<"application/onenote">>;
mime(<<".pdf">>) -> <<"application/pdf">>;
mime(<<".pgp">>) -> <<"application/pgp-encrypted">>;
mime(<<".key">>) -> <<"application/pgp-keys">>;
mime(<<".sig">>) -> <<"application/pgp-signature">>;
mime(<<".prf">>) -> <<"application/pics-rules">>;
mime(<<".ps">>) -> <<"application/postscript">>;
mime(<<".ai">>) -> <<"application/postscript">>;
mime(<<".eps">>) -> <<"application/postscript">>;
mime(<<".epsi">>) -> <<"application/postscript">>;
mime(<<".epsf">>) -> <<"application/postscript">>;
mime(<<".eps2">>) -> <<"application/postscript">>;
mime(<<".eps3">>) -> <<"application/postscript">>;
mime(<<".rar">>) -> <<"application/rar">>;
mime(<<".rdf">>) -> <<"application/rdf+xml">>;
mime(<<".rtf">>) -> <<"application/rtf">>;
mime(<<".stl">>) -> <<"application/sla">>;
mime(<<".smil">>) -> <<"application/smil+xml">>;
mime(<<".xhtml">>) -> <<"application/xhtml+xml">>;
mime(<<".xht">>) -> <<"application/xhtml+xml">>;
mime(<<".xml">>) -> <<"application/xml">>;
mime(<<".xsd">>) -> <<"application/xml">>;
mime(<<".xsl">>) -> <<"application/xslt+xml">>;
mime(<<".xslt">>) -> <<"application/xslt+xml">>;
mime(<<".xspf">>) -> <<"application/xspf+xml">>;
mime(<<".zip">>) -> <<"application/zip">>;
mime(<<".apk">>) -> <<"application/vnd.android.package-archive">>;
mime(<<".cdy">>) -> <<"application/vnd.cinderella">>;
mime(<<".ddeb">>) -> <<"application/vnd.debian.binary-package">>;
mime(<<".sfd">>) -> <<"application/vnd.font-fontforge-sfd">>;
mime(<<".kml">>) -> <<"application/vnd.google-earth.kml+xml">>;
mime(<<".kmz">>) -> <<"application/vnd.google-earth.kmz">>;
mime(<<".xul">>) -> <<"application/vnd.mozilla.xul+xml">>;
mime(<<".xls">>) -> <<"application/vnd.ms-excel">>;
mime(<<".xlb">>) -> <<"application/vnd.ms-excel">>;
mime(<<".xlt">>) -> <<"application/vnd.ms-excel">>;
mime(<<".xlam">>) -> <<"application/vnd.ms-excel.addin.macroEnabled.12">>;
mime(<<".xlsb">>) -> <<"application/vnd.ms-excel.sheet.binary.macroEnabled.12">>;
mime(<<".xlsm">>) -> <<"application/vnd.ms-excel.sheet.macroEnabled.12">>;
mime(<<".xltm">>) -> <<"application/vnd.ms-excel.template.macroEnabled.12">>;
mime(<<".eot">>) -> <<"application/vnd.ms-fontobject">>;
mime(<<".thmx">>) -> <<"application/vnd.ms-officetheme">>;
mime(<<".cat">>) -> <<"application/vnd.ms-pki.seccat">>;
mime(<<".ppt">>) -> <<"application/vnd.ms-powerpoint">>;
mime(<<".pps">>) -> <<"application/vnd.ms-powerpoint">>;
mime(<<".ppam">>) -> <<"application/vnd.ms-powerpoint.addin.macroEnabled.12">>;
mime(<<".pptm">>) -> <<"application/vnd.ms-powerpoint.presentation.macroEnabled.12">>;
mime(<<".sldm">>) -> <<"application/vnd.ms-powerpoint.slide.macroEnabled.12">>;
mime(<<".ppsm">>) -> <<"application/vnd.ms-powerpoint.slideshow.macroEnabled.12">>;
mime(<<".potm">>) -> <<"application/vnd.ms-powerpoint.template.macroEnabled.12">>;
mime(<<".docm">>) -> <<"application/vnd.ms-word.document.macroEnabled.12">>;
mime(<<".dotm">>) -> <<"application/vnd.ms-word.template.macroEnabled.12">>;
mime(<<".odc">>) -> <<"application/vnd.oasis.opendocument.chart">>;
mime(<<".odb">>) -> <<"application/vnd.oasis.opendocument.database">>;
mime(<<".odf">>) -> <<"application/vnd.oasis.opendocument.formula">>;
mime(<<".odg">>) -> <<"application/vnd.oasis.opendocument.graphics">>;
mime(<<".otg">>) -> <<"application/vnd.oasis.opendocument.graphics-template">>;
mime(<<".odi">>) -> <<"application/vnd.oasis.opendocument.image">>;
mime(<<".odp">>) -> <<"application/vnd.oasis.opendocument.presentation">>;
mime(<<".otp">>) -> <<"application/vnd.oasis.opendocument.presentation-template">>;
mime(<<".ods">>) -> <<"application/vnd.oasis.opendocument.spreadsheet">>;
mime(<<".ots">>) -> <<"application/vnd.oasis.opendocument.spreadsheet-template">>;
mime(<<".odt">>) -> <<"application/vnd.oasis.opendocument.text">>;
mime(<<".odm">>) -> <<"application/vnd.oasis.opendocument.text-master">>;
mime(<<".ott">>) -> <<"application/vnd.oasis.opendocument.text-template">>;
mime(<<".oth">>) -> <<"application/vnd.oasis.opendocument.text-web">>;
mime(<<".pptx">>) -> <<"application/vnd.openxmlformats-officedocument.presentationml.presentation">>;
mime(<<".sldx">>) -> <<"application/vnd.openxmlformats-officedocument.presentationml.slide">>;
mime(<<".ppsx">>) -> <<"application/vnd.openxmlformats-officedocument.presentationml.slideshow">>;
mime(<<".potx">>) -> <<"application/vnd.openxmlformats-officedocument.presentationml.template">>;
mime(<<".xlsx">>) -> <<"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet">>;
mime(<<".xltx">>) -> <<"application/vnd.openxmlformats-officedocument.spreadsheetml.template">>;
mime(<<".docx">>) -> <<"application/vnd.openxmlformats-officedocument.wordprocessingml.document">>;
mime(<<".dotx">>) -> <<"application/vnd.openxmlformats-officedocument.wordprocessingml.template">>;
mime(<<".cod">>) -> <<"application/vnd.rim.cod">>;
mime(<<".mmf">>) -> <<"application/vnd.smaf">>;
mime(<<".sdc">>) -> <<"application/vnd.stardivision.calc">>;
mime(<<".sds">>) -> <<"application/vnd.stardivision.chart">>;
mime(<<".sda">>) -> <<"application/vnd.stardivision.draw">>;
mime(<<".sdd">>) -> <<"application/vnd.stardivision.impress">>;
mime(<<".sdf">>) -> <<"application/vnd.stardivision.math">>;
mime(<<".sdw">>) -> <<"application/vnd.stardivision.writer">>;
mime(<<".sgl">>) -> <<"application/vnd.stardivision.writer-global">>;
mime(<<".sxc">>) -> <<"application/vnd.sun.xml.calc">>;
mime(<<".stc">>) -> <<"application/vnd.sun.xml.calc.template">>;
mime(<<".sxd">>) -> <<"application/vnd.sun.xml.draw">>;
mime(<<".std">>) -> <<"application/vnd.sun.xml.draw.template">>;
mime(<<".sxi">>) -> <<"application/vnd.sun.xml.impress">>;
mime(<<".sti">>) -> <<"application/vnd.sun.xml.impress.template">>;
mime(<<".sxm">>) -> <<"application/vnd.sun.xml.math">>;
mime(<<".sxw">>) -> <<"application/vnd.sun.xml.writer">>;
mime(<<".sxg">>) -> <<"application/vnd.sun.xml.writer.global">>;
mime(<<".stw">>) -> <<"application/vnd.sun.xml.writer.template">>;
mime(<<".sis">>) -> <<"application/vnd.symbian.install">>;
mime(<<".cap">>) -> <<"application/vnd.tcpdump.pcap">>;
mime(<<".pcap">>) -> <<"application/vnd.tcpdump.pcap">>;
mime(<<".vsd">>) -> <<"application/vnd.visio">>;
mime(<<".vst">>) -> <<"application/vnd.visio">>;
mime(<<".vsw">>) -> <<"application/vnd.visio">>;
mime(<<".vss">>) -> <<"application/vnd.visio">>;
mime(<<".wbxml">>) -> <<"application/vnd.wap.wbxml">>;
mime(<<".wmlc">>) -> <<"application/vnd.wap.wmlc">>;
mime(<<".wmlsc">>) -> <<"application/vnd.wap.wmlscriptc">>;
mime(<<".wpd">>) -> <<"application/vnd.wordperfect">>;
mime(<<".wp5">>) -> <<"application/vnd.wordperfect5.1">>;
mime(<<".wk">>) -> <<"application/x-123">>;
mime(<<".7z">>) -> <<"application/x-7z-compressed">>;
mime(<<".abw">>) -> <<"application/x-abiword">>;
mime(<<".dmg">>) -> <<"application/x-apple-diskimage">>;
mime(<<".bcpio">>) -> <<"application/x-bcpio">>;
mime(<<".torrent">>) -> <<"application/x-bittorrent">>;
mime(<<".cab">>) -> <<"application/x-cab">>;
mime(<<".cbr">>) -> <<"application/x-cbr">>;
mime(<<".cbz">>) -> <<"application/x-cbz">>;
mime(<<".cdf">>) -> <<"application/x-cdf">>;
mime(<<".cda">>) -> <<"application/x-cdf">>;
mime(<<".vcd">>) -> <<"application/x-cdlink">>;
mime(<<".pgn">>) -> <<"application/x-chess-pgn">>;
mime(<<".mph">>) -> <<"application/x-comsol">>;
mime(<<".cpio">>) -> <<"application/x-cpio">>;
mime(<<".csh">>) -> <<"application/x-csh">>;
mime(<<".deb">>) -> <<"application/x-debian-package">>;
mime(<<".udeb">>) -> <<"application/x-debian-package">>;
mime(<<".dcr">>) -> <<"application/x-director">>;
mime(<<".dir">>) -> <<"application/x-director">>;
mime(<<".dxr">>) -> <<"application/x-director">>;
mime(<<".dms">>) -> <<"application/x-dms">>;
mime(<<".wad">>) -> <<"application/x-doom">>;
mime(<<".dvi">>) -> <<"application/x-dvi">>;
mime(<<".pfa">>) -> <<"application/x-font">>;
mime(<<".pfb">>) -> <<"application/x-font">>;
mime(<<".gsf">>) -> <<"application/x-font">>;
mime(<<".pcf">>) -> <<"application/x-font-pcf">>;
mime(<<".pcf.Z">>) -> <<"application/x-font-pcf">>;
mime(<<".mm">>) -> <<"application/x-freemind">>;
mime(<<".spl">>) -> <<"application/x-futuresplash">>;
mime(<<".gan">>) -> <<"application/x-ganttproject">>;
mime(<<".gnumeric">>) -> <<"application/x-gnumeric">>;
mime(<<".sgf">>) -> <<"application/x-go-sgf">>;
mime(<<".gcf">>) -> <<"application/x-graphing-calculator">>;
mime(<<".gtar">>) -> <<"application/x-gtar">>;
mime(<<".tgz">>) -> <<"application/x-gtar-compressed">>;
mime(<<".taz">>) -> <<"application/x-gtar-compressed">>;
mime(<<".hdf">>) -> <<"application/x-hdf">>;
mime(<<".rhtml">>) -> <<"#application/x-httpd-eruby">>;
mime(<<".phtml">>) -> <<"#application/x-httpd-php">>;
mime(<<".pht">>) -> <<"#application/x-httpd-php">>;
mime(<<".php">>) -> <<"#application/x-httpd-php">>;
mime(<<".phps">>) -> <<"#application/x-httpd-php-source">>;
mime(<<".php3">>) -> <<"#application/x-httpd-php3">>;
mime(<<".php3p">>) -> <<"#application/x-httpd-php3-preprocessed">>;
mime(<<".php4">>) -> <<"#application/x-httpd-php4">>;
mime(<<".php5">>) -> <<"#application/x-httpd-php5">>;
mime(<<".hwp">>) -> <<"application/x-hwp">>;
mime(<<".ica">>) -> <<"application/x-ica">>;
mime(<<".info">>) -> <<"application/x-info">>;
mime(<<".ins">>) -> <<"application/x-internet-signup">>;
mime(<<".isp">>) -> <<"application/x-internet-signup">>;
mime(<<".iii">>) -> <<"application/x-iphone">>;
mime(<<".iso">>) -> <<"application/x-iso9660-image">>;
mime(<<".jam">>) -> <<"application/x-jam">>;
mime(<<".jnlp">>) -> <<"application/x-java-jnlp-file">>;
mime(<<".jmz">>) -> <<"application/x-jmol">>;
mime(<<".chrt">>) -> <<"application/x-kchart">>;
mime(<<".kil">>) -> <<"application/x-killustrator">>;
mime(<<".skp">>) -> <<"application/x-koan">>;
mime(<<".skd">>) -> <<"application/x-koan">>;
mime(<<".skt">>) -> <<"application/x-koan">>;
mime(<<".skm">>) -> <<"application/x-koan">>;
mime(<<".kpr">>) -> <<"application/x-kpresenter">>;
mime(<<".kpt">>) -> <<"application/x-kpresenter">>;
mime(<<".ksp">>) -> <<"application/x-kspread">>;
mime(<<".kwd">>) -> <<"application/x-kword">>;
mime(<<".kwt">>) -> <<"application/x-kword">>;
mime(<<".latex">>) -> <<"application/x-latex">>;
mime(<<".lha">>) -> <<"application/x-lha">>;
mime(<<".lyx">>) -> <<"application/x-lyx">>;
mime(<<".lzh">>) -> <<"application/x-lzh">>;
mime(<<".lzx">>) -> <<"application/x-lzx">>;
mime(<<".frm">>) -> <<"application/x-maker">>;
mime(<<".maker">>) -> <<"application/x-maker">>;
mime(<<".frame">>) -> <<"application/x-maker">>;
mime(<<".fm">>) -> <<"application/x-maker">>;
mime(<<".fb">>) -> <<"application/x-maker">>;
mime(<<".book">>) -> <<"application/x-maker">>;
mime(<<".fbdoc">>) -> <<"application/x-maker">>;
mime(<<".mif">>) -> <<"application/x-mif">>;
mime(<<".m3u8">>) -> <<"application/x-mpegURL">>;
mime(<<".wmd">>) -> <<"application/x-ms-wmd">>;
mime(<<".wmz">>) -> <<"application/x-ms-wmz">>;
mime(<<".com">>) -> <<"application/x-msdos-program">>;
mime(<<".exe">>) -> <<"application/x-msdos-program">>;
mime(<<".bat">>) -> <<"application/x-msdos-program">>;
mime(<<".dll">>) -> <<"application/x-msdos-program">>;
mime(<<".msi">>) -> <<"application/x-msi">>;
mime(<<".nc">>) -> <<"application/x-netcdf">>;
mime(<<".pac">>) -> <<"application/x-ns-proxy-autoconfig">>;
mime(<<".nwc">>) -> <<"application/x-nwc">>;
mime(<<".o">>) -> <<"application/x-object">>;
mime(<<".oza">>) -> <<"application/x-oz-application">>;
mime(<<".p7r">>) -> <<"application/x-pkcs7-certreqresp">>;
mime(<<".crl">>) -> <<"application/x-pkcs7-crl">>;
mime(<<".pyc">>) -> <<"application/x-python-code">>;
mime(<<".pyo">>) -> <<"application/x-python-code">>;
mime(<<".qgs">>) -> <<"application/x-qgis">>;
mime(<<".shp">>) -> <<"application/x-qgis">>;
mime(<<".shx">>) -> <<"application/x-qgis">>;
mime(<<".qtl">>) -> <<"application/x-quicktimeplayer">>;
mime(<<".rdp">>) -> <<"application/x-rdp">>;
mime(<<".rpm">>) -> <<"application/x-redhat-package-manager">>;
mime(<<".rss">>) -> <<"application/x-rss+xml">>;
mime(<<".rb">>) -> <<"application/x-ruby">>;
mime(<<".sci">>) -> <<"application/x-scilab">>;
mime(<<".sce">>) -> <<"application/x-scilab">>;
mime(<<".xcos">>) -> <<"application/x-scilab-xcos">>;
mime(<<".sh">>) -> <<"application/x-sh">>;
mime(<<".shar">>) -> <<"application/x-shar">>;
mime(<<".swf">>) -> <<"application/x-shockwave-flash">>;
mime(<<".swfl">>) -> <<"application/x-shockwave-flash">>;
mime(<<".scr">>) -> <<"application/x-silverlight">>;
mime(<<".sql">>) -> <<"application/x-sql">>;
mime(<<".sit">>) -> <<"application/x-stuffit">>;
mime(<<".sitx">>) -> <<"application/x-stuffit">>;
mime(<<".sv4cpio">>) -> <<"application/x-sv4cpio">>;
mime(<<".sv4crc">>) -> <<"application/x-sv4crc">>;
mime(<<".tar">>) -> <<"application/x-tar">>;
mime(<<".tcl">>) -> <<"application/x-tcl">>;
mime(<<".gf">>) -> <<"application/x-tex-gf">>;
mime(<<".pk">>) -> <<"application/x-tex-pk">>;
mime(<<".texinfo">>) -> <<"application/x-texinfo">>;
mime(<<".texi">>) -> <<"application/x-texinfo">>;
mime(<<".~">>) -> <<"application/x-trash">>;
mime(<<".%">>) -> <<"application/x-trash">>;
mime(<<".bak">>) -> <<"application/x-trash">>;
mime(<<".old">>) -> <<"application/x-trash">>;
mime(<<".sik">>) -> <<"application/x-trash">>;
mime(<<".t">>) -> <<"application/x-troff">>;
mime(<<".tr">>) -> <<"application/x-troff">>;
mime(<<".roff">>) -> <<"application/x-troff">>;
mime(<<".man">>) -> <<"application/x-troff-man">>;
mime(<<".me">>) -> <<"application/x-troff-me">>;
mime(<<".ms">>) -> <<"application/x-troff-ms">>;
mime(<<".ustar">>) -> <<"application/x-ustar">>;
mime(<<".src">>) -> <<"application/x-wais-source">>;
mime(<<".wz">>) -> <<"application/x-wingz">>;
mime(<<".crt">>) -> <<"application/x-x509-ca-cert">>;
mime(<<".xcf">>) -> <<"application/x-xcf">>;
mime(<<".fig">>) -> <<"application/x-xfig">>;
mime(<<".xpi">>) -> <<"application/x-xpinstall">>;
mime(<<".xz">>) -> <<"application/x-xz">>;
mime(<<".amr">>) -> <<"audio/amr">>;
mime(<<".awb">>) -> <<"audio/amr-wb">>;
mime(<<".axa">>) -> <<"audio/annodex">>;
mime(<<".au">>) -> <<"audio/basic">>;
mime(<<".snd">>) -> <<"audio/basic">>;
mime(<<".csd">>) -> <<"audio/csound">>;
mime(<<".orc">>) -> <<"audio/csound">>;
mime(<<".sco">>) -> <<"audio/csound">>;
mime(<<".flac">>) -> <<"audio/flac">>;
mime(<<".mid">>) -> <<"audio/midi">>;
mime(<<".midi">>) -> <<"audio/midi">>;
mime(<<".kar">>) -> <<"audio/midi">>;
mime(<<".mpga">>) -> <<"audio/mpeg">>;
mime(<<".mpega">>) -> <<"audio/mpeg">>;
mime(<<".mp2">>) -> <<"audio/mpeg">>;
mime(<<".mp3">>) -> <<"audio/mpeg">>;
mime(<<".m4a">>) -> <<"audio/mpeg">>;
mime(<<".oga">>) -> <<"audio/ogg">>;
mime(<<".ogg">>) -> <<"audio/ogg">>;
mime(<<".opus">>) -> <<"audio/ogg">>;
mime(<<".spx">>) -> <<"audio/ogg">>;
mime(<<".sid">>) -> <<"audio/prs.sid">>;
mime(<<".aif">>) -> <<"audio/x-aiff">>;
mime(<<".aiff">>) -> <<"audio/x-aiff">>;
mime(<<".aifc">>) -> <<"audio/x-aiff">>;
mime(<<".gsm">>) -> <<"audio/x-gsm">>;
mime(<<".m3u">>) -> <<"audio/x-mpegurl">>;
mime(<<".wma">>) -> <<"audio/x-ms-wma">>;
mime(<<".wax">>) -> <<"audio/x-ms-wax">>;
mime(<<".ra">>) -> <<"audio/x-pn-realaudio">>;
mime(<<".rm">>) -> <<"audio/x-pn-realaudio">>;
mime(<<".ram">>) -> <<"audio/x-pn-realaudio">>;
mime(<<".ra">>) -> <<"audio/x-realaudio">>;
mime(<<".pls">>) -> <<"audio/x-scpls">>;
mime(<<".sd2">>) -> <<"audio/x-sd2">>;
mime(<<".wav">>) -> <<"audio/x-wav">>;
mime(<<".alc">>) -> <<"chemical/x-alchemy">>;
mime(<<".cac">>) -> <<"chemical/x-cache">>;
mime(<<".cache">>) -> <<"chemical/x-cache">>;
mime(<<".csf">>) -> <<"chemical/x-cache-csf">>;
mime(<<".cbin">>) -> <<"chemical/x-cactvs-binary">>;
mime(<<".cascii">>) -> <<"chemical/x-cactvs-binary">>;
mime(<<".ctab">>) -> <<"chemical/x-cactvs-binary">>;
mime(<<".cdx">>) -> <<"chemical/x-cdx">>;
mime(<<".cer">>) -> <<"chemical/x-cerius">>;
mime(<<".c3d">>) -> <<"chemical/x-chem3d">>;
mime(<<".chm">>) -> <<"chemical/x-chemdraw">>;
mime(<<".cif">>) -> <<"chemical/x-cif">>;
mime(<<".cmdf">>) -> <<"chemical/x-cmdf">>;
mime(<<".cml">>) -> <<"chemical/x-cml">>;
mime(<<".cpa">>) -> <<"chemical/x-compass">>;
mime(<<".bsd">>) -> <<"chemical/x-crossfire">>;
mime(<<".csml">>) -> <<"chemical/x-csml">>;
mime(<<".csm">>) -> <<"chemical/x-csml">>;
mime(<<".ctx">>) -> <<"chemical/x-ctx">>;
mime(<<".cxf">>) -> <<"chemical/x-cxf">>;
mime(<<".cef">>) -> <<"chemical/x-cxf">>;
mime(<<".smi">>) -> <<"#chemical/x-daylight-smiles">>;
mime(<<".emb">>) -> <<"chemical/x-embl-dl-nucleotide">>;
mime(<<".embl">>) -> <<"chemical/x-embl-dl-nucleotide">>;
mime(<<".spc">>) -> <<"chemical/x-galactic-spc">>;
mime(<<".inp">>) -> <<"chemical/x-gamess-input">>;
mime(<<".gam">>) -> <<"chemical/x-gamess-input">>;
mime(<<".gamin">>) -> <<"chemical/x-gamess-input">>;
mime(<<".fch">>) -> <<"chemical/x-gaussian-checkpoint">>;
mime(<<".fchk">>) -> <<"chemical/x-gaussian-checkpoint">>;
mime(<<".cub">>) -> <<"chemical/x-gaussian-cube">>;
mime(<<".gau">>) -> <<"chemical/x-gaussian-input">>;
mime(<<".gjc">>) -> <<"chemical/x-gaussian-input">>;
mime(<<".gjf">>) -> <<"chemical/x-gaussian-input">>;
mime(<<".gal">>) -> <<"chemical/x-gaussian-log">>;
mime(<<".gcg">>) -> <<"chemical/x-gcg8-sequence">>;
mime(<<".gen">>) -> <<"chemical/x-genbank">>;
mime(<<".hin">>) -> <<"chemical/x-hin">>;
mime(<<".istr">>) -> <<"chemical/x-isostar">>;
mime(<<".ist">>) -> <<"chemical/x-isostar">>;
mime(<<".jdx">>) -> <<"chemical/x-jcamp-dx">>;
mime(<<".dx">>) -> <<"chemical/x-jcamp-dx">>;
mime(<<".kin">>) -> <<"chemical/x-kinemage">>;
mime(<<".mcm">>) -> <<"chemical/x-macmolecule">>;
mime(<<".mmd">>) -> <<"chemical/x-macromodel-input">>;
mime(<<".mmod">>) -> <<"chemical/x-macromodel-input">>;
mime(<<".mol">>) -> <<"chemical/x-mdl-molfile">>;
mime(<<".rd">>) -> <<"chemical/x-mdl-rdfile">>;
mime(<<".rxn">>) -> <<"chemical/x-mdl-rxnfile">>;
mime(<<".sd">>) -> <<"chemical/x-mdl-sdfile">>;
mime(<<".sdf">>) -> <<"chemical/x-mdl-sdfile">>;
mime(<<".tgf">>) -> <<"chemical/x-mdl-tgf">>;
mime(<<".mcif">>) -> <<"chemical/x-mmcif">>;
mime(<<".mol2">>) -> <<"chemical/x-mol2">>;
mime(<<".b">>) -> <<"chemical/x-molconn-Z">>;
mime(<<".gpt">>) -> <<"chemical/x-mopac-graph">>;
mime(<<".mop">>) -> <<"chemical/x-mopac-input">>;
mime(<<".mopcrt">>) -> <<"chemical/x-mopac-input">>;
mime(<<".mpc">>) -> <<"chemical/x-mopac-input">>;
mime(<<".zmt">>) -> <<"chemical/x-mopac-input">>;
mime(<<".moo">>) -> <<"chemical/x-mopac-out">>;
mime(<<".mvb">>) -> <<"chemical/x-mopac-vib">>;
mime(<<".asn">>) -> <<"chemical/x-ncbi-asn1">>;
mime(<<".prt">>) -> <<"chemical/x-ncbi-asn1-ascii">>;
mime(<<".ent">>) -> <<"chemical/x-ncbi-asn1-ascii">>;
mime(<<".val">>) -> <<"chemical/x-ncbi-asn1-binary">>;
mime(<<".aso">>) -> <<"chemical/x-ncbi-asn1-binary">>;
mime(<<".pdb">>) -> <<"chemical/x-pdb">>;
mime(<<".ros">>) -> <<"chemical/x-rosdal">>;
mime(<<".sw">>) -> <<"chemical/x-swissprot">>;
mime(<<".vms">>) -> <<"chemical/x-vamas-iso14976">>;
mime(<<".vmd">>) -> <<"chemical/x-vmd">>;
mime(<<".xtel">>) -> <<"chemical/x-xtel">>;
mime(<<".xyz">>) -> <<"chemical/x-xyz">>;
mime(<<".gif">>) -> <<"image/gif">>;
mime(<<".ief">>) -> <<"image/ief">>;
mime(<<".jp2">>) -> <<"image/jp2">>;
mime(<<".jpg2">>) -> <<"image/jp2">>;
mime(<<".jpeg">>) -> <<"image/jpeg">>;
mime(<<".jpg">>) -> <<"image/jpeg">>;
mime(<<".jpe">>) -> <<"image/jpeg">>;
mime(<<".jpm">>) -> <<"image/jpm">>;
mime(<<".jpx">>) -> <<"image/jpx">>;
mime(<<".jpf">>) -> <<"image/jpx">>;
mime(<<".pcx">>) -> <<"image/pcx">>;
mime(<<".png">>) -> <<"image/png">>;
mime(<<".svg">>) -> <<"image/svg+xml">>;
mime(<<".svgz">>) -> <<"image/svg+xml">>;
mime(<<".tiff">>) -> <<"image/tiff">>;
mime(<<".tif">>) -> <<"image/tiff">>;
mime(<<".djvu">>) -> <<"image/vnd.djvu">>;
mime(<<".djv">>) -> <<"image/vnd.djvu">>;
mime(<<".ico">>) -> <<"image/vnd.microsoft.icon">>;
mime(<<".wbmp">>) -> <<"image/vnd.wap.wbmp">>;
mime(<<".cr2">>) -> <<"image/x-canon-cr2">>;
mime(<<".crw">>) -> <<"image/x-canon-crw">>;
mime(<<".ras">>) -> <<"image/x-cmu-raster">>;
mime(<<".cdr">>) -> <<"image/x-coreldraw">>;
mime(<<".pat">>) -> <<"image/x-coreldrawpattern">>;
mime(<<".cdt">>) -> <<"image/x-coreldrawtemplate">>;
mime(<<".cpt">>) -> <<"image/x-corelphotopaint">>;
mime(<<".erf">>) -> <<"image/x-epson-erf">>;
mime(<<".art">>) -> <<"image/x-jg">>;
mime(<<".jng">>) -> <<"image/x-jng">>;
mime(<<".bmp">>) -> <<"image/x-ms-bmp">>;
mime(<<".nef">>) -> <<"image/x-nikon-nef">>;
mime(<<".orf">>) -> <<"image/x-olympus-orf">>;
mime(<<".psd">>) -> <<"image/x-photoshop">>;
mime(<<".pnm">>) -> <<"image/x-portable-anymap">>;
mime(<<".pbm">>) -> <<"image/x-portable-bitmap">>;
mime(<<".pgm">>) -> <<"image/x-portable-graymap">>;
mime(<<".ppm">>) -> <<"image/x-portable-pixmap">>;
mime(<<".rgb">>) -> <<"image/x-rgb">>;
mime(<<".xbm">>) -> <<"image/x-xbitmap">>;
mime(<<".xpm">>) -> <<"image/x-xpixmap">>;
mime(<<".xwd">>) -> <<"image/x-xwindowdump">>;
mime(<<".eml">>) -> <<"message/rfc822">>;
mime(<<".igs">>) -> <<"model/iges">>;
mime(<<".iges">>) -> <<"model/iges">>;
mime(<<".msh">>) -> <<"model/mesh">>;
mime(<<".mesh">>) -> <<"model/mesh">>;
mime(<<".silo">>) -> <<"model/mesh">>;
mime(<<".wrl">>) -> <<"model/vrml">>;
mime(<<".vrml">>) -> <<"model/vrml">>;
mime(<<".x3dv">>) -> <<"model/x3d+vrml">>;
mime(<<".x3d">>) -> <<"model/x3d+xml">>;
mime(<<".x3db">>) -> <<"model/x3d+binary">>;
mime(<<".appcache">>) -> <<"text/cache-manifest">>;
mime(<<".ics">>) -> <<"text/calendar">>;
mime(<<".icz">>) -> <<"text/calendar">>;
mime(<<".css">>) -> <<"text/css">>;
mime(<<".csv">>) -> <<"text/csv">>;
mime(<<".323">>) -> <<"text/h323">>;
mime(<<".html">>) -> <<"text/html">>;
mime(<<".htm">>) -> <<"text/html">>;
mime(<<".shtml">>) -> <<"text/html">>;
mime(<<".uls">>) -> <<"text/iuls">>;
mime(<<".mml">>) -> <<"text/mathml">>;
mime(<<".asc">>) -> <<"text/plain">>;
mime(<<".txt">>) -> <<"text/plain">>;
mime(<<".text">>) -> <<"text/plain">>;
mime(<<".pot">>) -> <<"text/plain">>;
mime(<<".brf">>) -> <<"text/plain">>;
mime(<<".srt">>) -> <<"text/plain">>;
mime(<<".rtx">>) -> <<"text/richtext">>;
mime(<<".sct">>) -> <<"text/scriptlet">>;
mime(<<".wsc">>) -> <<"text/scriptlet">>;
mime(<<".tm">>) -> <<"text/texmacs">>;
mime(<<".tsv">>) -> <<"text/tab-separated-values">>;
mime(<<".ttl">>) -> <<"text/turtle">>;
mime(<<".vcf">>) -> <<"text/vcard">>;
mime(<<".vcard">>) -> <<"text/vcard">>;
mime(<<".jad">>) -> <<"text/vnd.sun.j2me.app-descriptor">>;
mime(<<".wml">>) -> <<"text/vnd.wap.wml">>;
mime(<<".wmls">>) -> <<"text/vnd.wap.wmlscript">>;
mime(<<".bib">>) -> <<"text/x-bibtex">>;
mime(<<".boo">>) -> <<"text/x-boo">>;
mime(<<".h++">>) -> <<"text/x-c++hdr">>;
mime(<<".hpp">>) -> <<"text/x-c++hdr">>;
mime(<<".hxx">>) -> <<"text/x-c++hdr">>;
mime(<<".hh">>) -> <<"text/x-c++hdr">>;
mime(<<".c++">>) -> <<"text/x-c++src">>;
mime(<<".cpp">>) -> <<"text/x-c++src">>;
mime(<<".cxx">>) -> <<"text/x-c++src">>;
mime(<<".cc">>) -> <<"text/x-c++src">>;
mime(<<".h">>) -> <<"text/x-chdr">>;
mime(<<".htc">>) -> <<"text/x-component">>;
mime(<<".c">>) -> <<"text/x-csrc">>;
mime(<<".d">>) -> <<"text/x-dsrc">>;
mime(<<".diff">>) -> <<"text/x-diff">>;
mime(<<".patch">>) -> <<"text/x-diff">>;
mime(<<".hs">>) -> <<"text/x-haskell">>;
mime(<<".java">>) -> <<"text/x-java">>;
mime(<<".ly">>) -> <<"text/x-lilypond">>;
mime(<<".lhs">>) -> <<"text/x-literate-haskell">>;
mime(<<".moc">>) -> <<"text/x-moc">>;
mime(<<".p">>) -> <<"text/x-pascal">>;
mime(<<".pas">>) -> <<"text/x-pascal">>;
mime(<<".gcd">>) -> <<"text/x-pcs-gcd">>;
mime(<<".pl">>) -> <<"text/x-perl">>;
mime(<<".pm">>) -> <<"text/x-perl">>;
mime(<<".py">>) -> <<"text/x-python">>;
mime(<<".scala">>) -> <<"text/x-scala">>;
mime(<<".etx">>) -> <<"text/x-setext">>;
mime(<<".sfv">>) -> <<"text/x-sfv">>;
mime(<<".sh">>) -> <<"text/x-sh">>;
mime(<<".tcl">>) -> <<"text/x-tcl">>;
mime(<<".tk">>) -> <<"text/x-tcl">>;
mime(<<".tex">>) -> <<"text/x-tex">>;
mime(<<".ltx">>) -> <<"text/x-tex">>;
mime(<<".sty">>) -> <<"text/x-tex">>;
mime(<<".cls">>) -> <<"text/x-tex">>;
mime(<<".vcs">>) -> <<"text/x-vcalendar">>;
mime(<<".3gp">>) -> <<"video/3gpp">>;
mime(<<".axv">>) -> <<"video/annodex">>;
mime(<<".dl">>) -> <<"video/dl">>;
mime(<<".dif">>) -> <<"video/dv">>;
mime(<<".dv">>) -> <<"video/dv">>;
mime(<<".fli">>) -> <<"video/fli">>;
mime(<<".gl">>) -> <<"video/gl">>;
mime(<<".mpeg">>) -> <<"video/mpeg">>;
mime(<<".mpg">>) -> <<"video/mpeg">>;
mime(<<".mpe">>) -> <<"video/mpeg">>;
mime(<<".ts">>) -> <<"video/MP2T">>;
mime(<<".mp4">>) -> <<"video/mp4">>;
mime(<<".qt">>) -> <<"video/quicktime">>;
mime(<<".mov">>) -> <<"video/quicktime">>;
mime(<<".ogv">>) -> <<"video/ogg">>;
mime(<<".webm">>) -> <<"video/webm">>;
mime(<<".mxu">>) -> <<"video/vnd.mpegurl">>;
mime(<<".flv">>) -> <<"video/x-flv">>;
mime(<<".lsf">>) -> <<"video/x-la-asf">>;
mime(<<".lsx">>) -> <<"video/x-la-asf">>;
mime(<<".mng">>) -> <<"video/x-mng">>;
mime(<<".asf">>) -> <<"video/x-ms-asf">>;
mime(<<".asx">>) -> <<"video/x-ms-asf">>;
mime(<<".wm">>) -> <<"video/x-ms-wm">>;
mime(<<".wmv">>) -> <<"video/x-ms-wmv">>;
mime(<<".wmx">>) -> <<"video/x-ms-wmx">>;
mime(<<".wvx">>) -> <<"video/x-ms-wvx">>;
mime(<<".avi">>) -> <<"video/x-msvideo">>;
mime(<<".movie">>) -> <<"video/x-sgi-movie">>;
mime(<<".mpv">>) -> <<"video/x-matroska">>;
mime(<<".mkv">>) -> <<"video/x-matroska">>;
mime(<<".ice">>) -> <<"x-conference/x-cooltalk">>;
mime(<<".sisx">>) -> <<"x-epoc/x-sisx-app">>;
mime(<<".vrm">>) -> <<"x-world/x-vrml">>;
mime(_) -> <<"application/octet-stream">>.

